@@ -14,13 +14,19 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '3.1';    # VERSION
+our $VERSION = '3.2';    # VERSION
 my @OPTIONS_ATTRIBUTES
-    = qw/format short repeatable negativable autosplit doc required/;
+    = qw/format short repeatable negativable autosplit doc/;
 
 sub import {
     my ( undef, @import ) = @_;
-    my %import_options = ( protect_argv => 1, flavour => [], @import );
+    my %import_options
+        = ( protect_argv => 1, flavour => [], skip_options => [], @import );
+    my %skip_options;
+    if ( defined $import_options{skip_options} ) {
+        %skip_options
+            = map { ( $_ => 1 ) } @{ $import_options{skip_options} };
+    }
 
     my $target = caller;
     my $with   = $target->can('with');
@@ -40,9 +46,14 @@ sub import {
                 "You cannot use an option with the name '$ban', it is implied by MooX::Options"
                 if $name eq $ban;
         }
-        $_options_meta->{$name}
-            = { _validate_and_filter_options(%attributes) };
+
         $target->can('has')->( $name => _filter_attributes(%attributes) );
+
+        if ( !$skip_options{$name} ) {
+            $_options_meta->{$name}
+                = { _validate_and_filter_options(%attributes) };
+        }
+
         unless ($modifier_done) {
             $around->(
                 _options_meta => sub {
@@ -77,7 +88,7 @@ sub _validate_and_filter_options {
     $options{doc} = $options{documentation} if !defined $options{doc};
 
     my %cmdline_options = map { ( $_ => $options{$_} ) }
-        grep { exists $options{$_} } @OPTIONS_ATTRIBUTES;
+        grep { exists $options{$_} } @OPTIONS_ATTRIBUTES, 'required';
 
     $cmdline_options{repeatable} = 1 if $cmdline_options{autosplit};
     $cmdline_options{format} .= "@"
@@ -102,7 +113,7 @@ MooX::Options - add option keywords to your object (Mo/Moo/Moose)
 
 =head1 VERSION
 
-version 3.1
+version 3.2
 
 =head1 MooX::Options
 
@@ -139,6 +150,14 @@ by default, argv is protected. if you want to do something else on it, use this
 
     use MooX::Options protect_argv => 0;
 
+=item skip_options
+
+you can skip some option to remove the possibility to the terminal. in that case, the 'option' keyword will just works like an 'has'.
+
+    use MooX::Options skip_options => [qw/multi/];
+
+If you have multiple tools that use the same Role to generate params, you can skip one and force his value. In my example, it could be a multithread option that you want to disabling in some case.
+
 =back
 
 =back
