@@ -12,7 +12,7 @@ package MooX::Options::Role;
 use strict;
 use warnings;
 
-our $VERSION = '3.1';    # VERSION
+our $VERSION = '3.2';    # VERSION
 
 use MRO::Compat;
 use Moo::Role;
@@ -32,7 +32,6 @@ sub parse_options {
     my %metas          = $class->_options_meta;
     my %options_params = $class->_options_params;
     my @options;
-    my %cmdline_params;
 
     my $option_name = sub {
         my ( $name, %meta ) = @_;
@@ -94,12 +93,10 @@ sub parse_options {
     }
 
     my @missing_required;
+    my %cmdline_params = %params;
     for my $name ( keys %metas ) {
         my %meta = %{ $metas{$name} };
-        if ( defined $params{$name} ) {
-            $cmdline_params{$name} = $params{$name};
-        }
-        else {
+        if ( !defined $cmdline_params{$name} ) {
             $cmdline_params{$name} = $opt->$name();
         }
         push @missing_required, $name
@@ -146,7 +143,7 @@ MooX::Options::Role - role that is apply to your object
 
 =head1 VERSION
 
-version 3.1
+version 3.2
 
 =head1 METHODS
 
